#ifndef LYRICSWEBVIEW_H
#define LYRICSWEBVIEW_H

#include <QMainWindow>

//#include <QtMaemo5>
#include <QtWebKit>

namespace Ui {
    class LyricsWebView;
}

class webPage : public QWebPage {
        public: webPage();
        QString userAgentForUrl(const QUrl &url ) const;
};

class LyricsWebView : public QMainWindow
{
    Q_OBJECT

public:
    explicit LyricsWebView(QWidget *parent = 0);
    ~LyricsWebView();

    void setUrl(QString url);

private slots:
    void on_webView_urlChanged(const QUrl &arg1);

private:
    Ui::LyricsWebView *ui;
};

#endif // LYRICSWEBVIEW_H
